@@ -3,6 +3,8 @@
 
 from .preprocess import preprocess
 from .preprocess import sepTrain
+from .preprocess import shuffle
+from .preprocess import reshape
 from .preprocess import normalize
 
 from .model import createDefaultModel
